pub struct VoiceAgentStateEvent {
pub room_name: String,
pub state: i32,
}Fields
room_name: Stringstate: i32Implementations
Sourceimpl VoiceAgentStateEvent
impl VoiceAgentStateEvent
Sourcepub fn state(&self) -> VoiceAgentState
pub fn state(&self) -> VoiceAgentState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: VoiceAgentState)
pub fn set_state(&mut self, value: VoiceAgentState)
Sets state to the provided enum value.