pub struct VoiceSession {
pub room_name: String,
pub voice_id: String,
pub state: i32,
pub agent_state: i32,
pub access_token: String,
pub livekit_url: String,
pub created_at: Option<Timestamp>,
}Fields
room_name: Stringvoice_id: Stringstate: i32agent_state: i32access_token: Stringlivekit_url: Stringcreated_at: Option<Timestamp>Implementations
Sourceimpl VoiceSession
impl VoiceSession
Sourcepub fn state(&self) -> VoiceSessionState
pub fn state(&self) -> VoiceSessionState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: VoiceSessionState)
pub fn set_state(&mut self, value: VoiceSessionState)
Sets state to the provided enum value.
Sourcepub fn agent_state(&self) -> VoiceAgentState
pub fn agent_state(&self) -> VoiceAgentState
Returns the enum value of agent_state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_agent_state(&mut self, value: VoiceAgentState)
pub fn set_agent_state(&mut self, value: VoiceAgentState)
Sets agent_state to the provided enum value.