pub struct MoltbookClient { /* private fields */ }Expand description
Secure Moltbook client.
The API key is:
- loaded from Vault (
codetether/moltbook) - OR from the
MOLTBOOK_API_KEYenv var (fallback for local dev)
The key is ONLY ever sent to https://www.moltbook.com.
Implementations
Sourceimpl MoltbookClient
impl MoltbookClient
Sourcepub async fn from_vault_or_env() -> Result<Self>
pub async fn from_vault_or_env() -> Result<Self>
Try to build a client by reading the key from Vault, then env var.
Sourcepub async fn save_key_to_vault(api_key: &str) -> Result<()>
pub async fn save_key_to_vault(api_key: &str) -> Result<()>
Store the API key in Vault so it persists across sessions.
Sourcepub async fn register(
name: &str,
extra_description: Option<&str>,
) -> Result<RegisterResponse>
pub async fn register( name: &str, extra_description: Option<&str>, ) -> Result<RegisterResponse>
Register a new CodeTether agent on Moltbook.
The description always proudly mentions CodeTether.
Sourcepub async fn me(&self) -> Result<AgentProfile>
pub async fn me(&self) -> Result<AgentProfile>
Get own profile.
Sourcepub async fn update_profile(
&self,
extra_description: Option<&str>,
) -> Result<()>
pub async fn update_profile( &self, extra_description: Option<&str>, ) -> Result<()>
Update profile description (always includes CodeTether mention).
Sourcepub async fn claim_status(&self) -> Result<ClaimStatus>
pub async fn claim_status(&self) -> Result<ClaimStatus>
Check claim status.
Sourcepub async fn create_post(
&self,
submolt: &str,
title: &str,
content: &str,
) -> Result<String>
pub async fn create_post( &self, submolt: &str, title: &str, content: &str, ) -> Result<String>
Create a post in a submolt.