In-memory implementation of RalphStateStore
Used for tests and as a fallback when no external store is configured.
Structs
- InMemory
Store - In-memory state store backed by a RwLock
In-memory implementation of RalphStateStore
Used for tests and as a fallback when no external store is configured.