pub enum OutputCapability {
BulkSummarizable,
ExactContent,
Unknown,
}Expand description
What RLM is allowed to do with a tool’s output.
Variants
BulkSummarizable
Bulk web/aggregate output where a prose summary is an acceptable lossy projection.
ExactContent
Content-carrying output whose exact bytes may be needed later.
Unknown
Unknown tool. Treated as OutputCapability::ExactContent.