Build the CompletionRequest used to ask the router model for a plan.
Functions
- build_
router_ request - Construct the provider request carrying the router prompt.
Build the CompletionRequest used to ask the router model for a plan.