Default model selection per provider.
When a session has no explicit model configured we fall back to a
sensible default for the chosen provider. These defaults only apply when
the caller has not set SessionMetadata::model.
Default model selection per provider.
When a session has no explicit model configured we fall back to a
sensible default for the chosen provider. These defaults only apply when
the caller has not set SessionMetadata::model.