Module text

Module text 

Functions

extract_candidate_file_paths
Extracts candidate file paths from text that exist in the workspace.
extract_text_content
Extracts text content from a list of ContentParts.
latest_user_text
Returns the text of the latest user message in the session.
role_label
truncate_with_ellipsis
Truncates a string to max_chars and adds an ellipsis if needed.