pub enum JournalEntry {
Staged {
txn: TxnId,
at: DateTime<Utc>,
op: Op,
},
Rejected {
txn: TxnId,
at: DateTime<Utc>,
reason: RejectReason,
},
Committed {
txn: TxnId,
at: DateTime<Utc>,
},
}Expand description
A single line in the journal.
Variants
Staged
An op was proposed and reserved a transaction id.
Rejected
Validation failed for a staged op. The transaction does not commit and the state does not mutate.
Committed
A staged op passed validation (or skipped it) and committed.