Module counts

Module counts 

Input/output token counts with field names that match most provider APIs.

Structs

TokenCounts
Token counts using the input_tokens / output_tokens naming convention favoured by most provider wire formats (Anthropic, Bedrock, OpenAI v2).