pub struct PluginRegistry { /* private fields */ }Expand description
Plugin registry — tracks registered and verified plugins.
Implementations
Sourceimpl PluginRegistry
impl PluginRegistry
pub fn new(signing_key: SigningKey) -> Self
pub fn from_env() -> Self
Sourcepub async fn register(&self, manifest: PluginManifest) -> Result<()>
pub async fn register(&self, manifest: PluginManifest) -> Result<()>
Register a plugin manifest only when unsafe content bypass is enabled.
Sourcepub async fn register_bytes(
&self,
manifest: PluginManifest,
content: &[u8],
) -> Result<()>
pub async fn register_bytes( &self, manifest: PluginManifest, content: &[u8], ) -> Result<()>
Register a plugin after verifying its signature and byte content.
Sourcepub async fn register_file(
&self,
manifest: PluginManifest,
path: &Path,
) -> Result<()>
pub async fn register_file( &self, manifest: PluginManifest, path: &Path, ) -> Result<()>
Register a plugin after verifying its signature and file content.
Sourcepub async fn is_verified(&self, plugin_id: &str) -> bool
pub async fn is_verified(&self, plugin_id: &str) -> bool
Check if a plugin is registered and verified.
Sourcepub async fn get(&self, plugin_id: &str) -> Option<PluginManifest>
pub async fn get(&self, plugin_id: &str) -> Option<PluginManifest>
Get a plugin manifest.
Sourcepub async fn list(&self) -> Vec<PluginManifest>
pub async fn list(&self) -> Vec<PluginManifest>
List all registered plugins.
Sourcepub fn signing_key(&self) -> &SigningKey
pub fn signing_key(&self) -> &SigningKey
Get a reference to the signing key (for creating manifests).