Module file_picker

Module file_picker 

File picker UI for browsing and attaching files (including images).

Supports:

  • Navigating directories
  • Selecting text files (attached as code snippets)
  • Selecting image files (attached as base64 image attachments)

Structs

FilePickerEntry
A single entry in the file picker listing.

Functions

file_picker_enter
Handle Enter key in file picker — navigate into directories or select files.
file_picker_filter_backspace
Handle Backspace in the filter input.
file_picker_filter_push
Push a character to the filter.
file_picker_select_next
Select next entry.
file_picker_select_prev
Select previous entry.
is_image_file
Check if a file path has an image extension.
open_file_picker
Open the file picker at the given working directory.
render_file_picker
Render the file picker view.