handle_bus_g

Function handle_bus_g 

pub fn handle_bus_g(app: &mut App)
Jump to the bottom of the bus log and enable auto-scroll.

Triggered by pressing g while in Bus view mode.

Examples

handle_bus_g(&mut app);