Module helpers

Module helpers 

Small helper functions for smart switch.

Functions

extract_provider_from_model
Extracts provider name from a model reference (e.g. “minimax/MiniMax-M2” -> “minimax”).
should_execute_smart_switch
Returns true when the model changed compared to the current session model.
smart_switch_max_retries
Returns the max number of smart switch retries (from env or default).