Module retry

Module retry 

Retry scheduling logic.

Structs

PendingSmartSwitchRetry
A pending smart switch retry with the prompt and target model.

Functions

maybe_schedule_smart_switch_retry
Schedules a smart switch retry if the error is retryable and candidates exist.