AppState

Struct AppState 

pub struct AppState {
Show 92 fields pub view_mode: ViewMode, pub input_mode: InputMode, pub messages: Vec<ChatMessage>, pub input: String, pub input_cursor: usize, pub input_scroll: usize, pub chat_scroll: usize, pub chat_last_max_scroll: usize, pub tool_preview_scroll: usize, pub tool_preview_last_max_scroll: usize, pub status: String, pub processing: bool, pub session_id: Option<String>, pub sessions: Vec<SessionSummary>, pub selected_session: usize, pub session_filter: String, pub cwd_display: String, pub bus_log: BusLogState, pub swarm: SwarmViewState, pub ralph: RalphViewState, pub symbol_search: SymbolSearchState, pub slash_suggestions: Vec<String>, pub selected_slash_suggestion: usize, pub command_history: Vec<String>, pub history_index: Option<usize>, pub worker_id: Option<String>, pub worker_name: Option<String>, pub a2a_connected: bool, pub recent_tasks: Vec<String>, pub worker_bridge_registered_agents: HashSet<String>, pub worker_bridge_processing_state: Option<bool>, pub worker_task_queue: VecDeque<IncomingTask>, pub help_scroll: HelpScrollState, pub show_help: bool, pub available_models: Vec<String>, pub selected_model_index: usize, pub model_picker_active: bool, pub model_filter: String, pub streaming_text: String, pub processing_started_at: Option<Instant>, pub current_request_first_token_ms: Option<u64>, pub current_request_last_token_ms: Option<u64>, pub last_request_first_token_ms: Option<u64>, pub last_request_last_token_ms: Option<u64>, pub last_completion_model: Option<String>, pub last_completion_latency_ms: Option<u64>, pub last_completion_prompt_tokens: Option<usize>, pub last_completion_output_tokens: Option<usize>, pub last_tool_name: Option<String>, pub last_tool_latency_ms: Option<u64>, pub last_tool_success: Option<bool>, pub pending_images: Vec<ImageAttachment>, pub queued_steering: Vec<String>, pub auto_apply_edits: bool, pub allow_network: bool, pub slash_autocomplete: bool, pub use_worktree: bool, pub selected_settings_index: usize, pub mcp_registry: Arc<TuiMcpRegistry>, pub spawned_agents: HashMap<String, SpawnedAgent>, pub active_spawned_agent: Option<String>, pub streaming_agent_texts: HashMap<String, String>, pub cached_message_lines: Vec<Line<'static>>, pub cached_messages_len: usize, pub cached_max_width: usize, pub cached_streaming_snapshot: Option<String>, pub cached_processing: bool, pub cached_frozen_len: usize, pub watchdog_notification: Option<WatchdogNotification>, pub main_watchdog_root_prompt: Option<String>, pub main_last_event_at: Option<Instant>, pub main_watchdog_restart_count: u32, pub main_inflight_prompt: Option<String>, pub okr_repository: Option<Arc<OkrRepository>>, pub pending_okr_approval: Option<PendingOkrApproval>, pub pending_smart_switch_retry: Option<PendingSmartSwitchRetry>, pub smart_switch_retry_count: u32, pub smart_switch_attempted_models: Vec<String>, pub chat_sync_rx: Option<UnboundedReceiver<ChatSyncUiEvent>>, pub chat_sync_status: Option<String>, pub chat_sync_last_success: Option<String>, pub chat_sync_last_error: Option<String>, pub chat_sync_uploaded_bytes: u64, pub chat_sync_uploaded_batches: u64, pub autochat: AutochatState, pub file_picker_dir: PathBuf, pub file_picker_entries: Vec<FilePickerEntry>, pub file_picker_selected: usize, pub file_picker_filter: String, pub file_picker_active: bool, pub workspace: WorkspaceSnapshot, pub chat_layout_mode: ChatLayoutMode,
}

Fields

view_mode: ViewModeinput_mode: InputModemessages: Vec<ChatMessage>input: Stringinput_cursor: usizeinput_scroll: usizechat_scroll: usizechat_last_max_scroll: usizetool_preview_scroll: usizetool_preview_last_max_scroll: usizestatus: Stringprocessing: boolsession_id: Option<String>sessions: Vec<SessionSummary>selected_session: usizesession_filter: Stringcwd_display: Stringbus_log: BusLogStateswarm: SwarmViewStateralph: RalphViewStatesymbol_search: SymbolSearchStateslash_suggestions: Vec<String>selected_slash_suggestion: usizecommand_history: Vec<String>history_index: Option<usize>worker_id: Option<String>worker_name: Option<String>a2a_connected: boolrecent_tasks: Vec<String>worker_bridge_registered_agents: HashSet<String>worker_bridge_processing_state: Option<bool>worker_task_queue: VecDeque<IncomingTask>help_scroll: HelpScrollStateshow_help: boolavailable_models: Vec<String>selected_model_index: usizemodel_picker_active: boolmodel_filter: Stringstreaming_text: Stringprocessing_started_at: Option<Instant>current_request_first_token_ms: Option<u64>current_request_last_token_ms: Option<u64>last_request_first_token_ms: Option<u64>last_request_last_token_ms: Option<u64>last_completion_model: Option<String>last_completion_latency_ms: Option<u64>last_completion_prompt_tokens: Option<usize>last_completion_output_tokens: Option<usize>last_tool_name: Option<String>last_tool_latency_ms: Option<u64>last_tool_success: Option<bool>pending_images: Vec<ImageAttachment>queued_steering: Vec<String>auto_apply_edits: boolallow_network: boolslash_autocomplete: booluse_worktree: boolselected_settings_index: usizemcp_registry: Arc<TuiMcpRegistry>spawned_agents: HashMap<String, SpawnedAgent>active_spawned_agent: Option<String>streaming_agent_texts: HashMap<String, String>cached_message_lines: Vec<Line<'static>>cached_messages_len: usizecached_max_width: usizecached_streaming_snapshot: Option<String>cached_processing: boolcached_frozen_len: usizewatchdog_notification: Option<WatchdogNotification>main_watchdog_root_prompt: Option<String>main_last_event_at: Option<Instant>main_watchdog_restart_count: u32main_inflight_prompt: Option<String>okr_repository: Option<Arc<OkrRepository>>pending_okr_approval: Option<PendingOkrApproval>pending_smart_switch_retry: Option<PendingSmartSwitchRetry>smart_switch_retry_count: u32smart_switch_attempted_models: Vec<String>chat_sync_rx: Option<UnboundedReceiver<ChatSyncUiEvent>>chat_sync_status: Option<String>chat_sync_last_success: Option<String>chat_sync_last_error: Option<String>chat_sync_uploaded_bytes: u64chat_sync_uploaded_batches: u64autochat: AutochatStatefile_picker_dir: PathBuffile_picker_entries: Vec<FilePickerEntry>file_picker_selected: usizefile_picker_filter: Stringfile_picker_active: boolworkspace: WorkspaceSnapshotchat_layout_mode: ChatLayoutMode

Implementations

Source

impl AppState

pub fn push_history(&mut self, entry: String)

pub fn history_prev(&mut self) -> bool

pub fn history_next(&mut self) -> bool

Source

impl AppState

pub fn clamp_input_cursor(&mut self)

pub fn ensure_input_cursor_visible(&mut self, visible_width: usize)

pub fn move_cursor_left(&mut self)

pub fn move_cursor_right(&mut self)

pub fn move_cursor_word_left(&mut self)

pub fn move_cursor_word_right(&mut self)

pub fn move_cursor_home(&mut self)

pub fn move_cursor_end(&mut self)

Source

impl AppState

pub fn insert_char(&mut self, c: char)

pub fn insert_text(&mut self, text: &str)

pub fn delete_backspace(&mut self)

pub fn delete_forward(&mut self)

pub fn clear_input(&mut self)

Source

impl AppState

pub fn get_or_build_message_lines( &mut self, max_width: usize, ) -> Option<Vec<Line<'static>>>

Returns cached lines when still valid for max_width, or None.

Source

impl AppState

pub async fn refresh_available_models( &mut self, registry: Option<&Arc<ProviderRegistry>>, ) -> Result<()>

Refresh the available models list from the provider registry.

Errors

Returns an error if any provider call fails critically.

Source

impl AppState

pub fn filtered_models(&self) -> Vec<&str>

pub fn set_available_models(&mut self, models: Vec<String>)

pub fn open_model_picker(&mut self)

pub fn close_model_picker(&mut self)

pub fn model_select_prev(&mut self)

pub fn model_select_next(&mut self)

pub fn model_filter_push(&mut self, c: char)

pub fn model_filter_backspace(&mut self)

pub fn selected_model(&self) -> Option<&str>

Source

impl AppState

pub fn scroll_up(&mut self, amount: usize)

pub fn scroll_down(&mut self, amount: usize)

pub fn scroll_to_bottom(&mut self)

Set sentinel value — clamped to actual content height at render time.

pub fn scroll_to_top(&mut self)

pub fn set_chat_max_scroll(&mut self, max_scroll: usize)

pub fn scroll_tool_preview_up(&mut self, amount: usize)

pub fn scroll_tool_preview_down(&mut self, amount: usize)

pub fn reset_tool_preview_scroll(&mut self)

pub fn set_tool_preview_max_scroll(&mut self, max_scroll: usize)

Source

impl AppState

Source

impl AppState

pub fn settings_select_prev(&mut self)

pub fn settings_select_next(&mut self)

pub fn set_view_mode(&mut self, view_mode: ViewMode)

Source

impl AppState

Source

impl AppState

pub fn queue_steering(&mut self, value: impl Into<String>)

pub fn clear_steering(&mut self)

pub fn steering_count(&self) -> usize

pub fn steering_prompt_prefix(&self) -> Option<String>

Source

impl AppState

Source

impl AppState

pub fn set_worker_bridge(&mut self, worker_id: String, worker_name: String)

pub fn sync_worker_bridge_processing(&mut self, processing: bool)

pub fn register_worker_agent(&mut self, name: String)

pub fn push_recent_task(&mut self, task: String)

pub fn enqueue_worker_task(&mut self, task: IncomingTask)

pub fn dequeue_worker_task(&mut self) -> Option<IncomingTask>