refresh_audit_snapshot

Function refresh_audit_snapshot 

pub async fn refresh_audit_snapshot(state: &mut AuditViewState)
Pull fresh entries from the global audit log into state.

Called on each TUI tick. When the global audit log has not been initialized (e.g. running without the server), this is a cheap no-op.