pub fn render_git_view(
f: &mut Frame<'_>,
area: Rect,
state: &GitViewState,
status: &str,
)Expand description
Render the git status view into area of f.
pub fn render_git_view(
f: &mut Frame<'_>,
area: Rect,
state: &GitViewState,
status: &str,
)Render the git status view into area of f.