A2A Worker - connects to an A2A server to process tasks
Structs
- Cognition
Heartbeat Config - Heartbeat
State - Heartbeat state shared between the heartbeat task and the main worker
Enums
- Worker
Status - Worker status for heartbeat
Constants
- DEFAULT_
A2A_ SERVER_ URL - Default A2A server URL when none is configured
Functions
- generate_
worker_ id - register_
worker - run
- run_
with_ state - Run the A2A worker with shared state for HTTP server integration This variant accepts a WorkerServerState to communicate with the HTTP server
- start_
heartbeat - Start the heartbeat background task Returns a JoinHandle that can be used to cancel the heartbeat