detect_browser

Function detect_browser 

pub fn detect_browser() -> Option<PathBuf>
Return the detected external browser executable, if one is required.

Native TetherScript browserctl does not depend on Chromium or another external browser process, so this currently returns None.