Module session

Module session 

Session management

Sessions track the conversation history and state for agent interactions.

Structs

ImageAttachment
An image attachment to include with a message (from clipboard paste, etc.)
Session
A conversation session
SessionMetadata
SessionResult
Result from a session prompt
SessionSummary
Summary of a session for listing

Enums

SessionEvent
Events emitted during session processing for real-time UI updates

Functions

list_sessions
List all sessions
list_sessions_for_directory
List sessions scoped to a specific directory (workspace)
list_sessions_paged
List sessions for a directory with pagination.