Session management
Sessions track the conversation history and state for agent interactions.
Structs
- Image
Attachment - An image attachment to include with a message (from clipboard paste, etc.)
- Session
- A conversation session
- Session
Metadata - Session
Result - Result from a session prompt
- Session
Summary - Summary of a session for listing
Enums
- Session
Event - Events emitted during session processing for real-time UI updates
Functions
- list_
sessions - List all sessions
- list_
sessions_ for_ directory - List sessions scoped to a specific directory (workspace)
- list_
sessions_ paged - List sessions for a directory with pagination.