Pending-confirmation helpers for tool results.
Edit tools such as edit, multiedit, and write emit preview results
that must be explicitly confirmed before being applied to disk. This module
provides the small set of helpers that decide whether a tool result
requires confirmation, how to render the user-facing status message, and
how to auto-apply the confirmation when the session has
SessionMetadata::auto_apply_edits
enabled.