Functions
- extract_
candidate_ file_ paths - Extracts candidate file paths from text that exist in the workspace.
- extract_
text_ content - Extracts text content from a list of ContentParts.
- latest_
user_ text - Returns the text of the latest user message in the session.
- role_
label - truncate_
with_ ellipsis - Truncates a string to max_chars and adds an ellipsis if needed.