Tool telemetry
Per-tool execution tracking, including success/failure counts, duration, and the file changes each tool performed.
| File | Responsibility |
|---|---|
counter | AtomicToolCounter — lock-free success/failure counter |
file_change | FileChange records emitted by filesystem tools |
execution | ToolExecution — a single tool invocation record |
Re-exports
pub use counter::AtomicToolCounter;pub use execution::ToolExecution;pub use file_change::FileChange;
Modules
- counter
- Lock-free success/failure counter for tool invocations.
- execution
- A single tool invocation record with timing, outcome, and file changes.
- file_
change - Per-tool filesystem operation records.