Modules
- autochat
- Autochat relay integration for the TUI event loop.
- background
- codex_
sessions - commands
- event_
handlers - Keyboard, mouse and paste event dispatch for the TUI.
- event_
loop - Main TUI event loop orchestration.
- file_
picker - File picker UI for browsing and attaching files (including images).
- file_
preview - File preview: reads the first N bytes/lines of a file for picker display.
- file_
share - impl_
app - input
- Text input, Enter, backspace and paste handlers for TUI views.
- mcp
- message_
text - model_
picker - navigation
- okr_
gate - OKR Approval Gate for /go command
- panic_
cleanup - run
- session_
events - session_
sync - settings
- signal_
shutdown - slash_
hint_ match - Slash command hint matching for autocomplete preview.
- slash_
hints - Slash command hint descriptions for autocomplete.
- smart_
switch - Smart model switching on provider errors.
- state
- TUI application state — the central
AppStatestruct and its methods. - symbols
- terminal_
state - text
- watchdog
- Watchdog stalled-request recovery module.
- worker_
bridge