File picker UI for browsing and attaching files (including images).
Supports:
- Navigating directories
- Selecting text files (attached as code snippets)
- Selecting image files (attached as base64 image attachments)
Structs
- File
Picker Entry - A single entry in the file picker listing.
Functions
- file_
picker_ enter - Handle Enter key in file picker — navigate into directories or select files.
- file_
picker_ filter_ backspace - Handle Backspace in the filter input.
- file_
picker_ filter_ push - Push a character to the filter.
- file_
picker_ select_ next - Select next entry.
- file_
picker_ select_ prev - Select previous entry.
- is_
image_ file - Check if a file path has an image extension.
- open_
file_ picker - Open the file picker at the given working directory.
- render_
file_ picker - Render the file picker view.