Function handle_char
Source pub async fn handle_char(app: &mut App, modifiers: KeyModifiers, c: char)
Route a printable character to the correct view handler.
Depending on the active view mode, the character is sent
to symbol search, bus filter, model filter, file picker
filter, or the chat input buffer.
Examples
ⓘhandle_char(&mut app, modifiers, 'x').await;