Small helper functions for smart switch.
Functions
- extract_
provider_ from_ model - Extracts provider name from a model reference (e.g. “minimax/MiniMax-M2” -> “minimax”).
- should_
execute_ smart_ switch - Returns true when the model changed compared to the current session model.
- smart_
switch_ max_ retries - Returns the max number of smart switch retries (from env or default).